package Bencher::Scenarios::LogGer;

our $DATE = '2021-04-09'; # DATE
our $VERSION = '0.018'; # VERSION

1;
# ABSTRACT: Scenarios for benchmarking Log::ger

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::LogGer - Scenarios for benchmarking Log::ger

=head1 VERSION

This document describes version 0.018 of Bencher::Scenarios::LogGer (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::LogGer::InitTarget>

=item * L<Bencher::Scenario::LogGer::NullOutput>

=item * L<Bencher::Scenario::LogGer::OutputStartup>

=item * L<Bencher::Scenario::LogGer::NumericLevel>

=item * L<Bencher::Scenario::LogGer::LayoutStartup>

=item * L<Bencher::Scenario::LogGer::StringLevel>

=item * L<Bencher::Scenario::LogGer::Overhead>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-LogGer>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2018, 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
